import * as React from 'react';
import {Layout, Providers} from '@rx-suite/ui';
import './stores';
import {RxAppModel, RxAppStore} from '@rx-suite/stores';
import {routes} from "./routes";
import {observer} from "mobx-react-lite";
import {subscribe} from "@rx-suite/data";
import {t} from "@lingui/macro";
import {LinearProgress} from "@material-ui/core";

import 'react-table/react-table.css';
import 'tui-calendar/dist/tui-calendar.css';

subscribe();

export default observer(() => {
    const [messages, setMessages] = React.useState<any>(null);
    const model = RxAppStore.selectedModel as RxAppModel;
    React.useEffect(() => {
        if (model) {
            const getMessages = async () => {
                const compiledMessages = await import(`../../../locales/${model.language}/messages.mjs`);
                setMessages(compiledMessages.messages);
            }
            model.setTitleBase(t`Rx-Hub`);
            getMessages();
        }
    }, [model]);
    if (!model || !messages) {
        return <LinearProgress/>
    }
    return (
        <Providers theme={model.theme} language={model.language} messages={messages}>
            <Layout routes={routes}/>
        </Providers>
    )
});

