import * as React from "react";
import {observer} from "mobx-react-lite";
import {ButtonGroup, Table, TableBody, TableCell, TableRow} from "@material-ui/core";
import {ComponentPermissionRow} from "./ComponentPermissionRow"
import {useReadonlyContext} from "@rx-suite/ui/build";
import {t} from "@lingui/macro";
import TableHead from "@material-ui/core/TableHead";
import {ComponentPermissionGroup} from "./ComponentPermissionForm"
import {TabPanel, TabPanelProps} from "./TabPanel"
import {GrantedButton} from "./GrantedButton";
import {DeniedButton} from "./DeniedButton";

type ComponentPermissionTabProps = {
    components: Array<ComponentPermissionGroup>
} & TabPanelProps

export const ComponentPermissionTab: React.FunctionComponent<ComponentPermissionTabProps> = observer((props) => {
    const {components, value, index} = props;
    const readOnly = useReadonlyContext();

    const setAllForApp = function (granted: boolean) {
        components.forEach(component => {
            component.actions.forEach(action => {
                action.rolePermission.viewModel.permitted = granted;
            });
        });
    };

    return (
        <TabPanel value={value} index={index}>
            {!readOnly && <ButtonGroup color="primary" aria-label="outlined primary button group">
                <GrantedButton
                    onClick={() => setAllForApp(true)}
                >
                    {t`Grant all for App`}
                </GrantedButton>
                <DeniedButton
                    onClick={() => setAllForApp(false)}
                >
                    {t`Revoke all for App`}
                </DeniedButton>
            </ButtonGroup>}
            <Table aria-label="simple table">
                <TableHead>
                    <TableRow>
                        <TableCell>{t`Item`}</TableCell>
                        <TableCell align="left">{t`Permissions`}</TableCell>
                        {!readOnly && <TableCell align="right">{t`Quick Actions`}</TableCell>}
                    </TableRow>
                </TableHead>
                <TableBody>
                    {components.sort((a, b) => {
                        //Grouping by target_category first, followed by number of action and then display name
                        if((((a || {}).target || {}).target_category || '') === (((b || {}).target || {}).target_category || '')) {
                            if ((((b || {}).actions || []).length - ((a || {}).actions || []).length) != 0) {
                                return ((b || {}).actions || []).length - ((a || {}).actions || []).length;
                            }
                            return (((a || {}).target || {}).target_display_name || '').localeCompare(((b || {}).target || {}).target_display_name || '');
                        }
                        return (((a || {}).target || {}).target_category || '').localeCompare(((b || {}).target || {}).target_category || '');
                    }).map(component => <ComponentPermissionRow key={component.target.target_id as string}
                                                                component={component}/>)}
                </TableBody>
            </Table>
        </TabPanel>
    );
});
