import {observer} from "mobx-react-lite";
import React from "react";
import {EmailModel, EmailStore} from "../../stores/EmailStore";
import {Model} from "@rx-suite/data/build";
import {SelectField} from "@rx-suite/ui";
import {t} from "@lingui/macro";
import {LinearProgress} from "@material-ui/core";

type EmailSelectProps = {
    model: Model,
    readOnly?: boolean
}

export const EmailSelect: React.FunctionComponent<EmailSelectProps> = observer(({model, readOnly}) => {
    const handleChange = React.useCallback((name: string | undefined, value: any) => {
        model.nestedAssignment('email_id', value === '' ? null : value);
    }, [model]);
    React.useEffect(() => {
        EmailStore.getAll()
    }, []);
    const emails = EmailStore.models;

    if (emails) {
        let value = model.viewModel.email_id;
        if (value === null || value === undefined) {
            value = '';
        }

        const defaultOption = {label: t`Default`, value: ''};
        const emailOptions = Object.values(emails).filter((email: Model) => !email.isNew).map((email: EmailModel) => ({
            label: email.address, value: email.getId()
        }));

        const options = [defaultOption, ...emailOptions];
        const label = t`Email Address`;
        return <SelectField label={label} onChange={handleChange} value={value} options={options}
                            hint={{
                                title: label,
                                text: t`The email address this module will use when sending messages.`,
                            }}
                            disabled={readOnly}/>
    } else {
        return <LinearProgress color={'secondary'}/>
    }
});