import * as React from 'react';
import {ButtonField, useModelContext} from "@rx-suite/ui";
import {t, Trans} from "@lingui/macro";
import {useHistory} from "react-router-dom";
import {useSnackbar} from "notistack";
import {Permission, RoleModel} from "../../stores/RoleStore";
import {RolePermissionStore} from "../../stores/RolePermissionStore";
import {CurrentUserStore} from "@rx-suite/stores";

export const RoleFormSubmitButton = () => {
    const history = useHistory();
    const [isLoading, setIsLoading] = React.useState(false);
    const {enqueueSnackbar} = useSnackbar();
    const model = useModelContext() as RoleModel;

    const processDataChange = React.useCallback(async e => {
        e.preventDefault();

        const permissions = (model.permissions || []) as Permission[];

        if (!model.viewModel.isValid || !permissions.every((permission: Permission) => permission.rolePermission.viewModel.isValid)) {
            enqueueSnackbar(<Trans>Error saving record</Trans>, {variant: "error"});
            return;
        }

        setIsLoading(true);

        try {
            const json = await model.commit();
            console.log(json.permissions);

            RolePermissionStore.mapDataToIds(json.permissions);

            enqueueSnackbar(<Trans>Record saved</Trans>, {variant: "success"});
            history.push(`/roles/${json.role.id}/edit`);
            // you *must* be logged in to edit this form, so inform typescript it's ok
            // If you've somehow saved the roles permission form without being logged in we want a crash - that's a bad bug and we want it to be obvious
            if ((CurrentUserStore.selectedModel!.role! as { id: string }).id.toString() === model.getId().toString()) {
                CurrentUserStore.refreshData();
            }
        } catch(e) {
            console.error(e);
            enqueueSnackbar(<Trans>Error saving record</Trans>, {variant: "error"});
        } finally {
            setIsLoading(false);

        }
    }, [enqueueSnackbar, history, model]);

    return(
        <ButtonField
            variant="contained"
            color="primary"
            onClick={processDataChange}
            loading={isLoading}
            text={model.isNew ? t`Create Role` : t`Update Role`}
        />
    )
}