import * as React from "react";
import {observer} from "mobx-react-lite";
import {Schedule, ShiftModel} from "../../../stores/ShiftStore";
import {t} from "@lingui/macro";
import {InputField, SelectField} from "@rx-suite/ui";
import {makeStyles} from "@material-ui/core/styles";

const useStyles = makeStyles(theme => ({
    wrapper: {
        display: "flex",
        width: '100%',
        alignItems: 'flex-end',
        '& > *': {
            marginRight: theme.spacing(1)
        }
    }
}));

export const ShiftLengthField: React.FunctionComponent<{ shift: ShiftModel, schedule: Schedule, scheduleIndex: number, readOnly?: boolean }> = observer(({
                                                                                                                                                             shift,
                                                                                                                                                             schedule,
                                                                                                                                                             scheduleIndex,
                                                                                                                                                         }) => {
const classes = useStyles();
    const [lengthUnit, setLengthUnit] = React.useState<'minute' | 'hour'>('hour');
    const name = `shift_schedules[${scheduleIndex}].shift_length`;
    const convertedLength = (schedule.shift_length  === null) ? '' : (schedule.shift_length / ((lengthUnit === 'minute') ? 60 : 3600));
    const pluralLength = convertedLength !== 1;
    return (<div className={classes.wrapper}>
            <InputField label={t`For`} type={'number'} value={convertedLength}
                        inputProps={{min: 1, step: 1}}
                        name={name}
                        onChange={e => {
                            const value = (e.target.value === '') ? null :  (Number(e.target.value) * ((lengthUnit === 'minute') ? 60 : 3600));
                            shift.handleScheduleChange(scheduleIndex, {
                                ...shift.viewModel.shift_schedules[scheduleIndex],
                                shift_length: value
                            });
                        }}
                        error={!!shift.errors[name]}
                        helperText={shift.errors[name]}
            />
            <SelectField
                onChange={(_name, value) => {
                    setLengthUnit(value);
                }}
                value={lengthUnit}
                options={[
                    {label: pluralLength ? t`Minutes` : t`Minute`, value: 'minute'},
                    {label: pluralLength ? t`Hours` : t`Hour`, value: 'hour'}
                ]}/>
        </div>
    );
});