import * as React from "react";
import {ModelForm, ModelInput} from "@rx-suite/ui";
import {observer} from "mobx-react-lite";
import {TimeFormatConfigModel, TimeFormatConfigStore} from "../../stores/TimeFormatConfigStore";
import {Divider, LinearProgress, List, ListItem, ListItemSecondaryAction, ListItemText} from "@material-ui/core";
import {Trans} from "@lingui/macro";
import {TabPanel, TabPanelProps} from "../component_permissions/TabPanel";
import {CurrentUserStore, CurrentUserModel} from "@rx-suite/stores";

export const TimeFormatSettingTab: React.FunctionComponent<TabPanelProps> = observer((props) => {
    const {value, index} = props;

    const timeFormatConfig = TimeFormatConfigStore.selectedModel as unknown as TimeFormatConfigModel;
    const user = CurrentUserStore.selectedModel as CurrentUserModel;

    if(TimeFormatConfigStore.isLoading) {
        return <LinearProgress color={'secondary'}/>
    }

    if(!timeFormatConfig) {
        return null;
    }

    const dateFormatHintText = [
        {key: 'YYYY', text: 'Year'},
        {key: 'MM', text: 'Month'},
        {key: 'DD', text: 'Day'}
    ]

    const timeFormatHintText = [
        {key: 'HH', text: 'Hours (24h)'},
        {key: 'hh', text: 'Hours (12h)'},
        {key: 'mm', text: 'Minutes'},
        {key: 'ss', text: 'Seconds'},
        {key: 'A', text: 'AM/PM'},
    ]

    const dateFormatHint = (textHints: {key: string, text: string}[]) => {
        return (
            <div>
                <List dense>
                    {textHints.map((hintText) => {
                        return (
                            <div>
                                <ListItem>
                                    <ListItemText
                                        primary={hintText.key}
                                    />
                                    <ListItemSecondaryAction>
                                        <Trans>
                                            {hintText.text}
                                        </Trans>
                                    </ListItemSecondaryAction>
                                </ListItem>
                                <Divider/>
                            </div>
                        )
                    })}
                </List>
                <h4>
                    <Trans>
                        Formatters are Case Sensitive
                    </Trans>
                </h4>
                <a href="https://momentjscom.readthedocs.io/en/latest/moment/04-displaying/01-format/" target="_blank" rel="noopener noreferrer">
                    <Trans>
                        Moment library formatters
                    </Trans>
                </a>
            </div>
        )
    }

    return (
        <TabPanel value={value} index={index}>
            <ModelForm model={timeFormatConfig} readOnly={!user?.canUpdate("TimeFormatConfig")} suppressWrapper suppressMakeCopy suppressImportExport>
                <ModelInput name={'date_format'} hint={{title: 'Available Date Formatters', children: dateFormatHint(dateFormatHintText)}}/>
                <ModelInput name={'time_format'} hint={{title: 'Available Time Formatters', children: dateFormatHint(timeFormatHintText)}}/>
                <ModelInput name={'separator'}/>
            </ModelForm>
        </TabPanel>
    )
})