import * as React from 'react';
import {observer} from "mobx-react-lite";
import {ButtonField, PaddedPaper} from "@rx-suite/ui/build";
import {t} from "@lingui/macro";
import {UserModel} from "../../stores/UserStore";
import {VpnKey} from "@material-ui/icons";
import {Popover, Typography} from "@material-ui/core";
import copy from "clipboard-copy"

export const PasswordRecoveryCopyButton: React.FunctionComponent<{ user: UserModel }> = observer(({user}) => {
    const [anchor, setAnchor] = React.useState(null);
    const [pending, setPending] = React.useState(false);
    const open = !!anchor;
    const copyClick = React.useCallback(e => {
        setPending(true);
        const target = e.currentTarget;
        user.getPasswordResetLink().then((link) => {
            setPending(false);
            if (link) {
                copy(link);
                setAnchor(target);
            }
        });
    }, [setAnchor, setPending, user]);
    const closePopup = React.useCallback(() => {
        setAnchor(null);
    }, [setAnchor]);
    return <React.Fragment>
        <ButtonField text={t`Copy Password Recovery Link`}
                     startIcon={<VpnKey/>}
                     onClick={copyClick}
                     loading={pending}
                     tooltip={t`Copy a link the user can use to reset their password to your clipboard`}/>
        <Popover anchorEl={anchor} open={open}
                 onClose={closePopup}
                 anchorOrigin={{
                     vertical: 'bottom',
                     horizontal: 'center',
                 }}
                 transformOrigin={{
                     vertical: 'top',
                     horizontal: 'center',
                 }}
        >
            <PaddedPaper>
                <Typography variant={'caption'}>{t`Copied to clipboard!`}</Typography>
            </PaddedPaper>
        </Popover>
    </React.Fragment>
});