import * as React from 'react';
import {t} from "@lingui/macro";
import ReactTable, {Column, RowInfo} from "react-table";
import {installableApps, RxModulePackageModel, RxModulePackageStore} from "../../stores/RxModulePackageStore";
import {observer} from "mobx-react-lite";
import {LinkButton} from "@rx-suite/ui/build";
import {GetApp} from "@material-ui/icons";
import {currentUserCan} from "@rx-suite/stores/build";
import CSS from 'csstype';
import {useHistory} from 'react-router-dom';

export const AppInstallTable = observer(() => {
    const history = useHistory();
    const columns = [
        {
            Header: t`Module Code`,
            accessor: 'id'
        },
        {
            Header: t`Available Version`,
            accessor: 'highestAvailableUpdate'
        }
    ] as Column[];
    if (currentUserCan('Component', 'install')) {
        columns.push(
            {
                accessor: (d: RxModulePackageModel) => d,
                id: '_actions',
                width: 200,
                Cell: (cellInfo: { value: RxModulePackageModel }) => {
                    if (!cellInfo.value || !cellInfo.value.getId) {
                        return null;
                    }
                    return <>
                        <LinkButton startIcon={<GetApp/>}
                                    to={RxModulePackageStore.urlFor('install', cellInfo.value.getId())!}>
                            {t`Install`}
                        </LinkButton>
                    </>
                },
                sortable: false,
                filterable: false
            });
    }
    return (
        <ReactTable data={installableApps() as RxModulePackageModel[]} columns={columns}
                    getTdProps={(_: any, rowInfo: RowInfo | undefined, column: Column | undefined) => {
                        const props: { onClick?: React.MouseEventHandler, style: CSS.Properties } = {
                            style: {
                                textAlign: 'center'
                            }
                        };
                        if (currentUserCan('Component', 'install')) {
                            if (rowInfo && rowInfo.original && (column || {}).id !== '_actions') {
                                props.onClick = () => history.push(RxModulePackageStore.urlFor('install', rowInfo.original.getId())!);
                                props.style.cursor = 'pointer'
                            }
                        }
                        return props;
                    }}
        />
    )
});