import * as React from 'react';
import {observer} from "mobx-react-lite";
import {Conditional, ModelForm} from "@rx-suite/ui";
import {LinearProgress, Typography} from "@material-ui/core";
import {ModelInput} from "@rx-suite/ui/build";
import {LicenceInfoStore} from "../../stores/LicenceInfoStore";
import {currentUserCan} from "@rx-suite/stores/build";
import {t} from "@lingui/macro";
import {IfFalse} from "@rx-suite/ui/build/components/logic/IfFalse";
import {IfTrue} from "@rx-suite/ui/build/components/logic/IfTrue";
import moment from "moment";

export const LicenceForm: React.FunctionComponent = observer(() => {
    const model = LicenceInfoStore.selectedModel;
    const readOnly = !currentUserCan('licence_info', 'update')
    if (!model) {
        return <LinearProgress/>
    }
    return (
        <ModelForm model={model} readOnly={readOnly} suppressRedirect suppressImportExport>
            <ModelInput name={'licence_code'}/>
            <Typography variant={'body1'}>{model.label('last_check_attempt')}:&nbsp;
                <Conditional condition={!!model.last_check_attempt}>
                    <IfTrue>{moment(model.last_check_attempt as Date).format('YYYY-MM-DD HH:mm:ss')}</IfTrue>
                    <IfFalse>{t`Never`}</IfFalse>
                </Conditional>
            </Typography>
            <Typography variant={'body1'}>{model.label('last_successful_check')}:&nbsp;
                <Conditional condition={!!model.last_successful_check}>
                    <IfTrue>{moment(model.last_successful_check as Date).format('YYYY-MM-DD HH:mm:ss')}</IfTrue>
                    <IfFalse>{t`Never`}</IfFalse>
                </Conditional>
            </Typography>
            <Typography variant={'body1'}>{model.label('last_check_error')}:&nbsp;
                <Conditional condition={!!model.last_check_error}>
                    <IfTrue>{model.last_check_error}</IfTrue>
                    <IfFalse>{t`None`}</IfFalse>
                </Conditional>
            </Typography>
        </ModelForm>
    )
});
