import * as React from "react";
import {observer} from "mobx-react-lite";
import {t} from "@lingui/macro";
import {ComponentPermissionForm} from "../../components/component_permissions/ComponentPermissionForm";
import {
    FormProps,
    ModelInput,
    ModelProvider,
    PaddedPaper,
    ReadonlyProvider
} from "@rx-suite/ui";
import {LinearProgress} from "@material-ui/core";
import Typography from "@material-ui/core/Typography";
import {RxModuleComponentModel, RxModuleComponentStore} from "../../stores/RxModuleComponentStore";
import {Permission, RoleModel} from "../../stores/RoleStore";
import {RoleFormButton} from "../../components/roles/RoleFormButton";

type RolesFormProps = {
    model: RoleModel
} & Omit<FormProps, 'model'>

export const RolesForm: React.FunctionComponent<RolesFormProps> = observer(({model, readOnly}) => {

    const apps = (RxModuleComponentStore.getAll() as RxModuleComponentModel[]).filter(app => ['RxModuleComponent', 'RxUniverseApiComponent'].includes(app.type));

    const permissions = (model.permissions || []) as Permission[];

    if (RxModuleComponentStore.isLoading && permissions.length === 0) {
        return <LinearProgress color={'secondary'}/>;
    }

    return (
        <PaddedPaper>
            <Typography variant={'h4'}>{t`Role Information`}</Typography>
            <ReadonlyProvider value={!!readOnly}>
                <ModelProvider value={model}>
                    <ModelInput name={"name"}/>
                    <Typography variant={'h4'}>{t`Role Permissions`}</Typography>
                    <ComponentPermissionForm permissions={permissions} apps={apps}/>
                    <RoleFormButton />
                </ModelProvider>
            </ReadonlyProvider>
        </PaddedPaper>
    )
});