import * as React from 'react';
import {observer} from "mobx-react-lite";
import {FormProps} from "@rx-suite/ui";
import {Accordion, AccordionDetails, AccordionSummary, Container, Grid, Typography} from "@material-ui/core";
import {Trans} from "@lingui/macro";
import {ExpandMore} from '@material-ui/icons';
import {ShiftsBreadModel} from "../../components/shifts/ShiftsBreadModel";
import {ShiftsCalendar} from "../../components/shifts/ShiftsCalendar";
import {useLocation} from 'react-router-dom';
import {CalendarConfigStore} from "../../stores/CalendarConfigStore";

export const Shifts: React.FunctionComponent<FormProps> = observer(() => {
    const location = useLocation();
    const [formOpen, setFormOpen] = React.useState(true);
    const [calendarOpen, setCalendarOpen] = React.useState(true);

    React.useEffect(() => {
        if (location.pathname.includes('create') || location.pathname.includes('edit') || location.pathname.includes('read')) {
            setFormOpen(true);
            window.scrollTo(0, 0);
        }
    }, [location.pathname, setFormOpen])

    return (
        <Container maxWidth={false}>
            <Grid container spacing={2}>
                <Grid item xs={12}>
                    <Accordion expanded={formOpen} onChange={(_, open) => setFormOpen(open)}>
                        <AccordionSummary expandIcon={<ExpandMore/>}>
                            <Typography variant={'h4'}><Trans>Shifts</Trans></Typography>
                        </AccordionSummary>
                        <AccordionDetails>
                            <ShiftsBreadModel/>
                        </AccordionDetails>
                    </Accordion>
                </Grid>
                <Grid item xs={12}>
                    <Accordion expanded={calendarOpen} onChange={(_, open) => setCalendarOpen(open)}>
                        <AccordionSummary expandIcon={<ExpandMore/>}>
                            <Typography variant={'h4'}><Trans>Calendar</Trans></Typography>
                        </AccordionSummary>
                        <AccordionDetails>
                            <div style={{
                                width: '100%',
                                minHeight: (150 + (((CalendarConfigStore.selectedModel?.span as number) || 12) * 50)),
                                display: 'flex',
                                flexDirection: 'column'
                            }}>
                                <ShiftsCalendar/>
                            </div>
                        </AccordionDetails>
                    </Accordion>
                </Grid>
            </Grid>
        </Container>
    )
});
