import * as React from "react";
import {FormProps} from "@rx-suite/ui";
import {observer} from "mobx-react-lite";
import {Box, Tab, Tabs, Typography} from "@material-ui/core";
import {t, Trans} from "@lingui/macro";
import {TimeFormatSettingTab} from "../../components/system_settings/TimeFormatSettingTab";
import {PaddedPaper} from "@rx-suite/ui/build";
import {CurrentUserStore, CurrentUserModel} from "@rx-suite/stores";

export const SystemSettingForm: React.FunctionComponent<FormProps> = observer(() => {
    const [currentTab, setCurrentTab] = React.useState(0);
    const handleChange = (event: any, newValue: React.SetStateAction<number>) => {
        setCurrentTab(newValue);
    };

    const user = CurrentUserStore.selectedModel as CurrentUserModel;
    const canRead = user?.canRead("TimeFormatConfig")
    const [TabHeaders, TabPages] = React.useMemo(() => {
        const headers = [];
        const pages = [];
        if(canRead) {
            headers.push(<Tab label={t`Date & Time Formats`} key={0} />);
            pages.push(<TimeFormatSettingTab index={0} value={currentTab} />);
        }
        return [headers, pages];
    }, [canRead, currentTab]);

    if(!TabHeaders.length) {
        return(
            <PaddedPaper>
                <Box display={"flex"} justifyContent={"center"}>
                    <Typography variant={"h3"}>
                        <Trans>You don't have permission to view any system settings</Trans>
                    </Typography>
                </Box>
            </PaddedPaper>
        )
    }

    return (
        <PaddedPaper>
            <Tabs value={currentTab} onChange={handleChange} indicatorColor="primary"  textColor="primary" variant="scrollable">
                {TabHeaders}
            </Tabs>
            {TabPages}
        </PaddedPaper>
    )
})