import * as React from 'react';
import {observer} from "mobx-react-lite";
import {FormProps, ModelForm, ModelInput, ModelSelect, PaddedPaper} from "@rx-suite/ui";
import {RoleStore} from "../../stores/RoleStore";
import {Model} from "@rx-suite/data";
import {LinearProgress} from "@material-ui/core";
import {UserModel} from "../../stores/UserStore";
import {UserFormButtons} from "../../components/users/UserFormButtons";

export const UserForm: React.FunctionComponent<FormProps> = observer(({model, readOnly}) => {
    return (
        <PaddedPaper>
            <ModelForm model={model} readOnly={readOnly}
                       suppressWrapper
                       postFormActions={<UserFormButtons user={model as UserModel}/>}>
                <ModelInput name={"name"}/>
                <ModelInput name={"email"}/>
                <ModelSelect name={"table_size"} options={
                    [
                        {label: "5", value: 5},
                        {label: "10", value: 10},
                        {label: "20", value: 20},
                        {label: "25", value: 25},
                        {label: "50", value: 50},
                        {label: "100", value: 100}
                    ]
                }
                />
                {RoleStore.getAll() ? <ModelSelect name={"role_id"} options={
                        Object.values(RoleStore.getAll()).filter((role: Model) => !role.isNew).map((role: Model) => ({
                            label: role.name as string, value: role.getId()
                        }))}/>
                    : <LinearProgress color={'secondary'}/>
                }
            </ModelForm>
        </PaddedPaper>
    )
});
