import {attribute, Model, model, Transport} from '@rx-suite/data';
import * as yup from 'yup';
import {t} from "@lingui/macro";
import {computedFn} from "mobx-utils";
import {action, computed} from "mobx";
import semver from "semver";
import {RxModuleComponentStore} from "./RxModuleComponentStore";

@model({
    transportLayer: new Transport("/api/packages", "rx_module_package"),
    eager: true,
    routingInfo: {
        list: '/apps?tab=install',
        install: '/install/:id'
    },
})
export class RxModulePackageModel extends Model {
    @attribute({
        label: t`Versions`,
        validation: yup.array().of(yup.string())
    })
    versions: string[] = [];

    @attribute({
        label: t`Installable`,
        validation: yup.boolean()
    })
    installable = false;

    @computed
    get isNew() {
        return this.installable;
    }

    @computed
    get highestAvailableUpdate() {
        if (!this.versions.length) {
            return false;
        }
        let version = this.versions[0];
        this.versions.forEach(v => {
            if (semver.gt(v, version)) {
                version = v;
            }
        });
        return version
    }

    @attribute({
        label: t`Port`,
        validation: yup.number().min(0, t`Port must be a number greater than 0`)
    })
    port = 0;

    @action.bound
    findPort() {
        // We don't actually check if the port is in use - we just find the largest allocated rxmodule port, then go one step farther
        let port = 3849
        RxModuleComponentStore.getAll().forEach(mod => {
            port = Math.max(port, Number(mod.port));
        });
        RxModulePackageStore.getAll().forEach(pack => {
            port = Math.max(port, Number(pack.viewModel.port));
        });
        port += 1;
        this.viewModel.port = port;
    }
}

export const RxModulePackageStore = RxModulePackageModel.store;
RxModulePackageStore.setLimit(10000);

export const installableApps = computedFn(() => {
    return RxModulePackageStore.getAll().filter(p => p.installable);
})