# == Schema Information
#
# Table name: o_auths
#
#  id            :bigint           not null, primary key
#  access_token  :string(4000)
#  expires_at    :datetime
#  refresh_token :string(4000)
#  refresh_url   :string(4000)
#  service       :integer
#  created_at    :datetime         not null
#  updated_at    :datetime         not null
#  user_id       :bigint           not null
#
# Indexes
#
#  index_o_auths_on_user_id  (user_id)
#
# Foreign Keys
#
#  fk_rails_...  (user_id => users.id) ON DELETE => cascade
#
class OAuth < ApplicationRecord
  enum service: [:rxuniverse]
  belongs_to :user

  def current_token!
    if expires_at < (DateTime.now + 20.seconds)
      refresh_token!
    end
    access_token
  end

  def refresh_token!
    conn = Faraday.new(refresh_url, ssl: {
      verify: !RxModule::Communicator.skip_ssl_validation
    })
    response = conn.post(nil, JSON.generate({code: refresh_token}))
    json = JSON.parse(response.body)
    unless json["access_token"].empty?
      update(
        access_token: json["access_token"],
        refresh_token: json["refresh_token"],
        expires_at: DateTime.now + json["expires_in"].to_i.seconds
      )
    end
  end
end
