# == Schema Information
#
# Table name: roles
#
#  id         :bigint           not null, primary key
#  name       :string(4000)
#  created_at :datetime         not null
#  updated_at :datetime         not null
#
class Role < ApplicationRecord
  has_many :users
  has_many :role_permissions, dependent: :destroy
  has_many :component_permissions, through: :role_permissions

  accepts_nested_attributes_for :role_permissions

  validates :name, presence: true

  class << self
    def revoke_from_all(component_permission)
      Role.all.each do |role|
        role.revoke(component_permission)
      end
    end
  end

  def grant(component_permission)
    role_permissions.find_or_create_by(component_permission_id: component_permission.id).tap do |rp|
      rp.permitted = true
    end.save
  end

  def revoke(component_permission)
    role_permissions.find_or_create_by(component_permission_id: component_permission.id).tap do |rp|
      rp.permitted = false
    end.save
  end

  def flat_permissions
    role_permissions.eager_load(component_permission: :component).map(&:flat)
  end

  alias_method :permissions, :flat_permissions
end
