# == Schema Information
#
# Table name: components
#
#  id                :bigint           not null, primary key
#  description       :string(4000)
#  has_token         :boolean
#  ip_address        :string(4000)
#  is_api            :boolean
#  is_updating       :boolean
#  last_update_error :string(4000)
#  module_name       :string(4000)
#  port              :integer
#  protocol          :string(4000)     default("http")
#  reachable         :boolean
#  token             :string(4000)
#  type              :string(4000)
#  update_status     :string(4000)
#  version           :string(4000)
#  created_at        :datetime         not null
#  updated_at        :datetime         not null
#  email_id          :bigint
#  module_id         :string(4000)
#
# Indexes
#
#  index_components_on_email_id             (email_id)
#  index_components_on_module_id            (module_id) UNIQUE
#  index_components_on_port_and_ip_address  (port,ip_address) UNIQUE
#
# Foreign Keys
#
#  fk_rails_...  (email_id => emails.id) ON DELETE => nullify
#
class RouterApiComponent < Component
  before_save :set_module_values

  def set_module_values
    self.module_id = module_identifier
    self.module_name = "Router API"
    self.description = "Manages the Router API for posting MES data from Rx-Data."
    self.is_api = true
  end

  def module_identifier
    "router_api"
  end

  def ping
    response = RxModule::Communicator.call_module_method(module_identifier, "/status", :get)
    update({
      version: response[:version],
      reachable: true
    })
  rescue
    Rails.logger.warn { {msg: "Component may be offline or returning invalid responses", component: as_json} }
    update(reachable: false)
  end
end
